@@ -13,14 +13,9 @@ import base64
 
 def get_apns_certificate(cert_path, cert_pw):
     p12 = crypto.load_pkcs12(open(cert_path, 'rb').read(), cert_pw)
-    pem = crypto.dump_certificate(crypto.FILETYPE_PEM, p12.get_certificate())
-    print(pem)
-    print(pem.decode("ascii"))
-    print(pem.decode("utf-8"))
-    message_bytes = pem.decode("utf-8").encode('ascii')
-    base64_bytes = base64.b64encode(message_bytes)
-    base64_message = base64_bytes.decode('ascii')
-    return base64_message
+    pem = crypto.dump_certificate(crypto.FILETYPE_PEM, p12.get_certificate()) 
+    cert_str = pem.decode("utf-8").replace("\n","\\n")
+    return cert_str
 
 
 class NotificationStack(Stack): 
